@@ -3,13 +3,12 @@ Component for the estimation of the calibration coefficients  events
 """
 
 import numpy as np
-import h5py
 from ctapipe.core import Component
 from ctapipe.core import traits
-from ctapipe.core.traits import  Float, List, Path
+from ctapipe.core.traits import  Float, List
 from lstchain.calib.camera.flatfield import FlatFieldCalculator
 from lstchain.calib.camera.pedestals import PedestalCalculator
-from ctapipe.containers import EventType
+from lstchain.io.lstcontainers import LSTEventType
 
 __all__ = [
     'CalibrationCalculator',
@@ -36,25 +35,19 @@ class CalibrationCalculator(Component):
     kwargs
 
     """
-
-    systematic_correction_path = Path(
-        exists=True, directory_ok=False,
-        help='Path to systematic correction file ',
-    ).tag(config=True)
-
     squared_excess_noise_factor = Float(
-        1.222,
+        1.2,
         help='Excess noise factor squared: 1+ Var(gain)/Mean(Gain)**2'
     ).tag(config=True)
 
-    pedestal_product = traits.create_class_enum_trait(
+    pedestal_product = traits.enum_trait(
         PedestalCalculator,
-        default_value='PedestalIntegrator'
+        default='PedestalIntegrator'
     )
 
-    flatfield_product = traits.create_class_enum_trait(
+    flatfield_product = traits.enum_trait(
         FlatFieldCalculator,
-        default_value='FlasherFlatFieldCalculator'
+        default='FlasherFlatFieldCalculator'
     )
 
     classes = List([
@@ -68,7 +61,6 @@ class CalibrationCalculator(Component):
 
     def __init__(
         self,
-        subarray,
         parent=None,
         config=None,
         **kwargs
@@ -93,19 +85,13 @@ class CalibrationCalculator(Component):
 
         super().__init__(parent=parent, config=config,**kwargs)
 
-        if self.squared_excess_noise_factor<=0:
-            msg="Argument squared_excess_noise_factor must have a positive value"
-            raise ValueError(msg)
-
         self.flatfield = FlatFieldCalculator.from_name(
             self.flatfield_product,
-            parent=self,
-            subarray = subarray
+            parent=self
         )
         self.pedestal = PedestalCalculator.from_name(
             self.pedestal_product,
-            parent=self,
-            subarray = subarray
+            parent=self
         )
 
         msg = "tel_id not the same for all calibration components"
@@ -114,16 +100,6 @@ class CalibrationCalculator(Component):
 
         self.tel_id = self.flatfield.tel_id
 
-        # load systematic correction term B
-        self.quadratic_term = 0
-        if self.systematic_correction_path is not None:
-            try:
-                with h5py.File(self.systematic_correction_path, 'r') as hf:
-                    self.quadratic_term = np.array(hf['B_term'])
-
-            except:
-                raise IOError(f"Problem in reading quadratic term file {self.systematic_correction_path}")
-
         self.log.debug(f"{self.pedestal}")
         self.log.debug(f"{self.flatfield}")
 
@@ -132,8 +108,31 @@ class LSTCalibrationCalculator(CalibrationCalculator):
     """
     Calibration calculator for LST camera
     Fills the MonitoringCameraContainer on the base of calibration events
+
+    Parameters:
+    ----------
+    minimum_hg_charge_median :
+              Temporary cut on HG charge till the calibox TIB do not work
+             (default for filter 5.2)
+
+    maximum_lg_charge_std
+             Temporary cut on LG std against Lidar events till the calibox TIB do not work
+            (default for filter 5.2)
+
+    time_calibration_path:
+            Path with the drs4 time calibration corrections
     """
 
+    minimum_hg_charge_median = Float(
+        5000,
+        help='Temporary cut on HG charge till the calibox TIB do not work (default for filter 5.2)'
+    ).tag(config=True)
+
+    maximum_lg_charge_std = Float(
+        300,
+        help='Temporary cut on LG std against Lidar events till the calibox TIB do not work (default for filter 5.2) '
+    ).tag(config=True)
+
 
     def calculate_calibration_coefficients(self, event):
         """
@@ -142,7 +141,7 @@ class LSTCalibrationCalculator(CalibrationCalculator):
 
         Parameters
         ----------
-        event: ArrayArrayEventContainer
+        event: EventAndMonDataContainer
 
         """
 
@@ -154,48 +153,42 @@ class LSTCalibrationCalculator(CalibrationCalculator):
         # mask from pedestal and flat-field data
         monitoring_unusable_pixels = np.logical_or(status_data.pedestal_failing_pixels,
                                                    status_data.flatfield_failing_pixels)
-
         # calibration unusable pixels are an OR of all masks
         calib_data.unusable_pixels = np.logical_or(monitoring_unusable_pixels,
                                                    status_data.hardware_failing_pixels)
 
-        signal = ff_data.charge_median - ped_data.charge_median
-
         # Extract calibration coefficients with F-factor method
         # Assume fixed excess noise factor must be known from elsewhere
-        numerator = ff_data.charge_std ** 2 - ped_data.charge_std ** 2
-        denominator = self.squared_excess_noise_factor  * signal
-        gain = np.divide(numerator, denominator, out=np.zeros_like(numerator), where=denominator != 0)
-
-        # correct for the quadratic term (which is zero if not given)
-        systematic_correction = self.quadratic_term**2 * signal / self.squared_excess_noise_factor
-        gain -= systematic_correction
 
         # calculate photon-electrons
-        numerator = signal
-        denominator = gain
-
+        numerator = self.squared_excess_noise_factor  * (ff_data.charge_median - ped_data.charge_median) ** 2
+        denominator = ff_data.charge_std ** 2 - ped_data.charge_std ** 2
         n_pe = np.divide(numerator, denominator, out=np.zeros_like(numerator), where=denominator != 0)
 
         # fill WaveformCalibrationContainer
         calib_data.time = ff_data.sample_time
-        calib_data.time_min = ff_data.sample_time_min
-        calib_data.time_max = ff_data.sample_time_max
+        calib_data.time_range = ff_data.sample_time_range
         calib_data.n_pe = n_pe
 
-        # find signal median of good pixels over the camera (FF factor=<npe>/npe)
+        # find signal median of good pixels
         masked_npe = np.ma.array(n_pe, mask=calib_data.unusable_pixels)
         npe_signal_median = np.ma.median(masked_npe, axis=1)
 
-        # flat-fielded calibration coefficients
-        numerator = npe_signal_median[:,np.newaxis]
-        denominator = signal
-        calib_data.dc_to_pe = np.divide(numerator, denominator, out=np.zeros_like(denominator), where=denominator != 0)
+        # Flat field factor
+        numerator = npe_signal_median[:, np.newaxis]
+        denominator = n_pe
+        ff = np.divide(numerator, denominator, out=np.zeros_like(denominator), where=denominator != 0)
 
-        # flat-field time corrections
-        calib_data.time_correction = -ff_data.relative_time_median
+        # calibration coefficients
+        numerator = n_pe * ff
+        denominator = (ff_data.charge_median - ped_data.charge_median)
+        calib_data.dc_to_pe = np.divide(numerator, denominator, out=np.zeros_like(numerator), where=denominator != 0)
 
-        calib_data.pedestal_per_sample = ped_data.charge_median / self.pedestal.extractor.window_width.tel[self.tel_id]
+        # put the time around zero
+        camera_time_median = np.median(ff_data.time_median, axis=1)
+        calib_data.time_correction = -ff_data.relative_time_median - camera_time_median[:, np.newaxis]
+
+        calib_data.pedestal_per_sample = ped_data.charge_median / self.pedestal.extractor.window_width
 
         # put to zero unusable pixels
         calib_data.dc_to_pe[calib_data.unusable_pixels] = 0
@@ -213,20 +206,28 @@ class LSTCalibrationCalculator(CalibrationCalculator):
         new_ped = False
         new_ff = False
 
-        # if pedestal event:
-        if event.trigger.event_type == EventType.SKY_PEDESTAL:
+        # if pedestal event
+        if LSTEventType.is_pedestal(event.r1.tel[self.tel_id].trigger_type): 
 
             new_ped = self.pedestal.calculate_pedestals(event)
 
-        # if flat-field event:
-        elif event.trigger.event_type == EventType.FLATFIELD:
+
+        # if flat-field event: no calibration  TIB for the moment,
+        # use a cut on the charge for ff events and on std for rejecting Magic Lidar events
+        elif LSTEventType.is_calibration(event.r1.tel[self.tel_id].trigger_type) or (
+                np.median(np.sum(event.r1.tel[self.tel_id].waveform[0], axis=1))
+                > self.minimum_hg_charge_median
+                and np.std(np.sum(event.r1.tel[self.tel_id].waveform[1], axis=1))
+                < self.maximum_lg_charge_std):
 
             new_ff = self.flatfield.calculate_relative_gain(event)
 
+
             # if new ff, calculate new calibration coefficients
             if new_ff:
                 self.calculate_calibration_coefficients(event)
 
+
         return new_ped, new_ff
 
     def output_interleaved_results(self, event):
@@ -249,4 +250,4 @@ class LSTCalibrationCalculator(CalibrationCalculator):
                 self.calculate_calibration_coefficients(event)
                 new_ff = True
 
-        return new_ped, new_ff
+        return new_ped, new_ff
\ No newline at end of file
