@@ -2,12 +2,12 @@
 Factory for the estimation of the flat field coefficients
 """
 
-
+import os
 import numpy as np
 from astropy import units as u
 from ctapipe.calib.camera.flatfield import FlatFieldCalculator
-from ctapipe.core.traits import  List
-
+from ctapipe.core.traits import  List, Unicode
+from lstchain.calib.camera.pulse_time_correction import PulseTimeCorrection
 
 __all__ = [
     'FlasherFlatFieldCalculator'
@@ -43,8 +43,14 @@ class FlasherFlatFieldCalculator(FlatFieldCalculator):
         [-3, 3],
         help='Interval (number of std) of accepted charge standard deviation around camera median value'
     ).tag(config=True)
+    time_calibration_path = Unicode(
+        None,
+        allow_none = True,
+        help = 'Path to drs4 time calibration file'
+    ).tag(config = True)
 
     def __init__(self, **kwargs):
+
         """Calculates flat-field parameters from flasher data
            based on the best algorithm described by S. Fegan in MST-CAM-TN-0060 (eq. 19)
            Pixels are defined as outliers on the base of a cut on the pixel charge median
@@ -74,6 +80,19 @@ class FlasherFlatFieldCalculator(FlatFieldCalculator):
         self.arrival_times = None  # arrival time per event in sample
         self.sample_masked_pixels = None  # masked pixels per event in sample
 
+        if self.time_calibration_path is None:
+            self.time_corrector = None
+        else:
+        # look for calibration path otherwise
+            if os.path.exists(self.time_calibration_path):
+                self.time_corrector = PulseTimeCorrection(
+                calib_file_path = self.time_calibration_path)
+            else:
+                msg=f"Time calibration file {self.time_calibration_path} not found!"
+                raise IOError(msg)
+
+
+
     def _extract_charge(self, event):
         """
         Extract the charge and the time from a calibration event
@@ -96,6 +115,10 @@ class FlasherFlatFieldCalculator(FlatFieldCalculator):
 
             charge, peak_pos = self.extractor(waveforms)
 
+            # correct time with drs4 correction if available
+            if self.time_corrector:
+                peak_pos = self.time_corrector.get_corr_pulse(event, peak_pos)
+
         return charge, peak_pos
 
     def calculate_relative_gain(self, event):
@@ -118,20 +141,20 @@ class FlasherFlatFieldCalculator(FlatFieldCalculator):
         if self.num_events_seen == self.sample_size:
             self.num_events_seen = 0
 
+        pixel_mask = np.logical_or(
+            event.mon.tel[self.tel_id].pixel_status.hardware_failing_pixels,
+            event.mon.tel[self.tel_id].pixel_status.flatfield_failing_pixels)
+
         # real data
         if event.meta['origin'] != 'hessio':
             self.trigger_time = event.r1.tel[self.tel_id].trigger_time
 
-            pixel_mask = np.logical_or(
-                event.mon.tel[self.tel_id].pixel_status.hardware_failing_pixels,
-                event.mon.tel[self.tel_id].pixel_status.flatfield_failing_pixels)
         else:  # patches for MC data
             if event.trig.tels_with_trigger:
                 self.trigger_time = event.trig.gps_time.unix
             else:
                 self.trigger_time = 0
 
-            pixel_mask = np.zeros(waveform.shape[1], dtype=bool)
 
         if self.num_events_seen == 0:
             self.time_start = self.trigger_time
@@ -141,14 +164,17 @@ class FlasherFlatFieldCalculator(FlatFieldCalculator):
         # the peak position (assumed as time for the moment)
         charge, arrival_time = self._extract_charge(event)
 
+        # correct pulse time with drs4 corrections
+
+
         self.collect_sample(charge, pixel_mask, arrival_time)
 
         sample_age = self.trigger_time - self.time_start
 
         # check if to create a calibration event
-        if (
-            sample_age > self.sample_duration
-            or self.num_events_seen == self.sample_size
+        if (self.num_events_seen > 0 and
+                (sample_age > self.sample_duration or
+                self.num_events_seen == self.sample_size)
         ):
             # update the monitoring container
             self.store_results(event)
@@ -169,7 +195,6 @@ class FlasherFlatFieldCalculator(FlatFieldCalculator):
         if self.num_events_seen == 0:
             raise ValueError("No flat-field events in statistics, zero results")
 
-
         container = event.mon.tel[self.tel_id].flatfield
 
         # mask the part of the array not filled
