@@ -18,7 +18,7 @@ from ctapipe.core import Container, Field
 
 class DL1DataCheckContainer(Container):
     """
-    Container to store the subrun-wise outcome of the DL1 data check
+    Container to store outcome of the DL1 data check
     """
 
     geomlogger = logging.getLogger('ctapipe.instrument.camera')
@@ -28,10 +28,8 @@ class DL1DataCheckContainer(Container):
     subrun_index = Field(-1, 'Subrun index')
     elapsed_time = Field(-1, 'Subrun time duration (from Dragon)')
     num_events = Field(-1, 'Total number of events')
-    num_cleaned_events = Field(-1, 'Number of events surviving cleaning')
     trigger_type = Field(None, 'Number of events per trigger type')
     ucts_trigger_type = Field(None, 'Number of events per ucts trigger type')
-    num_ucts_jumps = Field(-1, 'Number of observed (and corrected) UCTS jumps')
     mean_alt_tel = Field(None, 'Mean telescope altitude')
     mean_az_tel = Field(None, 'Mean telescope azimuth')
 
@@ -119,13 +117,10 @@ class DL1DataCheckContainer(Container):
         self.elapsed_time = table['dragon_time'][len(table)-1] - \
                             table['dragon_time'][0]
         self.num_events = mask.sum()
-        self.num_cleaned_events = np.isfinite(table['intensity'][mask]).sum()
         self.ucts_trigger_type = \
             count_trig_types(table['ucts_trigger_type'][mask])
         self.trigger_type = \
             count_trig_types(table['trigger_type'][mask])
-        if 'ucts_jump' in table.columns:
-            self.num_ucts_jumps = np.sum(table['ucts_jump'][mask])
         self.mean_alt_tel = np.mean(table['alt_tel'])
         self.mean_az_tel = np.mean(table['az_tel'])
 
@@ -134,12 +129,9 @@ class DL1DataCheckContainer(Container):
         n_jump = 1+int(self.num_events/n_samples)
         # keep some info every n-jump-th event:
         sampled_event_ids = np.array(table['event_id'][mask][0::n_jump])
-        tib_time = u.Quantity(np.array(table['tib_time'][mask][0::n_jump]),
-                              u.s, copy=False)
-        ucts_time = u.Quantity(np.array(table['ucts_time'][mask][0::n_jump]),
-                               u.s, copy=False)
-        dragon_time = u.Quantity(np.array(table['dragon_time'][mask][
-                                          0::n_jump]), u.s, copy=False)
+        tib_time = np.array(table['tib_time'][mask][0::n_jump])
+        ucts_time = np.array(table['ucts_time'][mask][0::n_jump])
+        dragon_time = np.array(table['dragon_time'][mask][0::n_jump])
         # in case the resulting number of entries is <n_samples, we have to pad
         # the arrays, because hdf vector columns must have the same number of
         # elements in each row. We repeat the last value in the array
@@ -167,7 +159,7 @@ class DL1DataCheckContainer(Container):
                                  bins=histogram_binnings.hist_nislands)
         self.hist_nislands = counts
 
-        intensity = table.loc[mask, 'intensity'].to_numpy()
+        intensity = table['intensity'][mask]
         counts, _, _ = plt.hist(intensity,
                                 bins=histogram_binnings.hist_intensity)
         self.hist_intensity = counts
@@ -181,42 +173,33 @@ class DL1DataCheckContainer(Container):
                      bins=histogram_binnings.hist_dist0_intensity_gt_200)
         self.hist_dist0_intensity_gt_200 = counts
 
-        counts, _, _, _ = plt.hist2d(intensity,
-                                     table.loc[mask, 'width'].to_numpy(),
+        counts, _, _, _ = plt.hist2d(table['intensity'][mask],
+                                     table['width'][mask],
                                      bins=histogram_binnings.hist_width)
         self.hist_width = counts
 
-        counts, _, _, _ = plt.hist2d(intensity,
-                                     table.loc[mask, 'length'].to_numpy(),
+        counts, _, _, _ = plt.hist2d(table['intensity'][mask],
+                                     table['length'][mask],
                                      bins=histogram_binnings.hist_length)
         self.hist_length = counts
 
-        counts, _, _, _ = plt.hist2d(intensity,
-                                     table.loc[mask, 'skewness'].to_numpy(),
+        counts, _, _, _ = plt.hist2d(table['intensity'][mask],
+                                     table['skewness'][mask],
                                      bins=histogram_binnings.hist_skewness)
         self.hist_skewness = counts
 
-        psi = table.loc[mask, 'psi'].to_numpy()
-        counts, _, _ = \
-            plt.hist(psi, bins=histogram_binnings.hist_psi)
-        self.hist_psi = counts
-
+        intercept = table['intercept'][mask]
         counts, _, _, _ = \
-            plt.hist2d(intensity, table.loc[mask, 'intercept'].to_numpy(),
+            plt.hist2d(intensity, intercept,
                        bins=histogram_binnings.hist_intercept)
         self.hist_intercept = counts
 
-        length = table.loc[mask, 'length'].to_numpy()
-        tgrad = np.abs(table.loc[mask, 'time_gradient'].to_numpy())
+        length = table['length'][mask]
+        tgrad = np.abs(table['time_gradient'][mask])
         counts, _, _, _ = \
             plt.hist2d(length, tgrad,
                        bins=histogram_binnings.hist_tgrad_vs_length)
         self.hist_tgrad_vs_length = counts
-
-        # We noticed an occasional pyplot error that seems to be fixed by
-        # making sure that the coordinates passed to hist2d are ndarrays
-        # (instead of Pandas data series)
-
         counts, _, _, _ = \
             plt.hist2d(length[intensity > 200], tgrad[intensity > 200],
                        bins=histogram_binnings.
@@ -282,7 +265,7 @@ class DL1DataCheckContainer(Container):
         # containing very little signal. For time plots we require at least 1
         # p.e. We will also exclude NaNs from the calculations
 
-        time = table.col('peak_time')[mask]
+        time = table.col('pulse_time')[mask]
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=RuntimeWarning)
 
@@ -367,20 +350,20 @@ class DL1DataCheckHistogramBins(Container):
     # 2d histograms
     # width and length vs. image intensity:
     hist_width = Field(np.array([np.logspace(0.7, 5.7, 101),
-                                 np.linspace(0., 0.8, 101)]),
+                                 np.linspace(0., 1.2, 101)]),
                        'hist_width binning')
     hist_length = Field(np.array([np.logspace(0.7, 5.7, 101),
-                                  np.linspace(0., 1., 101)]),
+                                  np.linspace(0., 2., 101)]),
                         'hist_length binning')
     hist_skewness = Field(np.array([np.logspace(0.7, 5.7, 101),
                                     np.linspace(-4., 4., 101)]),
                           'hist_skewness binning')
     # time gradient vs. length:
-    hist_tgrad_vs_length = Field(np.array([np.linspace(0., 1.0, 101),
+    hist_tgrad_vs_length = Field(np.array([np.linspace(0., 2.0, 101),
                                            np.linspace(0., 200., 101)]),
                                  'hist_tgrad_vs_length binning')
     hist_tgrad_vs_length_intensity_gt_200 =\
-        Field(np.array([np.linspace(0., 1.0, 101), np.linspace(0., 50., 101)]),
+        Field(np.array([np.linspace(0., 2.0, 101), np.linspace(0., 50., 101)]),
               'hist_tgrad_vs_length_intensity_gt_200 binning')
     # time intercept (image time @ charge c.o.g.) vs. image intensity:
     hist_intercept = Field(np.array([np.logspace(0.7, 5.7, 101),
