@@ -1,15 +1,16 @@
 import numpy as np
-from ..io.lstcontainers import DispContainer
+from ..io import lstcontainers
 from . import utils
 import astropy.units as u
 
-__all__ = ['disp',
-           'miss',
-           'disp_parameters',
-           'disp_parameters_event',
-           'disp_vector',
-           'disp_to_pos'
-           ]
+__all__ = [
+    'disp',
+    'miss',
+    'disp_parameters',
+    'disp_parameters_event',
+    'disp_vector',
+    'disp_to_pos'
+    ]
 
 
 def disp(cog_x, cog_y, src_x, src_y):
@@ -106,7 +107,7 @@ def disp_parameters_event(hillas_parameters, source_pos_x, source_pos_y):
     -------
     `lstchain.io.containers.DispContainer`
     """
-    disp_container = DispContainer()
+    disp_container = lstcontainers.DispContainer()
 
     d = disp(hillas_parameters.x.to(u.m).value,
              hillas_parameters.y.to(u.m).value,
@@ -162,4 +163,4 @@ def disp_to_pos(disp_dx, disp_dy, cog_x, cog_y):
     source_pos_x = cog_x + disp_dx
     source_pos_y = cog_y + disp_dy
 
-    return source_pos_x, source_pos_y
\ No newline at end of file
+    return source_pos_x, source_pos_y
