@@ -9,22 +9,15 @@ Usage:
 
 $> python lstchain_add_source_dependent_parameters.py 
 --input-file dl1_LST-1.Run02033.0137.h5 
---config lstchain_src_dep_config.json
 
 """
 
 import os
 import argparse
 import pandas as pd
-from ctapipe.instrument import SubarrayDescription
 from lstchain.reco.dl1_to_dl2 import get_source_dependent_parameters
-from lstchain.io import read_configuration_file, get_standard_config
-from lstchain.io.io import(
-    dl1_params_lstcam_key,
-    dl1_params_src_dep_lstcam_key,
-    write_dataframe,
-    global_metadata
-)
+from lstchain.io import read_configuration_file
+from lstchain.io.io import dl1_params_src_dep_lstcam_key, write_dataframe, dl1_params_lstcam_key
 
 
 parser = argparse.ArgumentParser(description="Add the source dependent parameters to a DL1 file")
@@ -48,7 +41,7 @@ def main():
 
     dl1_filename = os.path.abspath(args.input_file)
 
-    config = get_standard_config()
+    config = {}
     if args.config_file is not None:
         try:
             config = read_configuration_file(os.path.abspath(args.config_file))
@@ -56,15 +49,10 @@ def main():
             pass
 
     dl1_params = pd.read_hdf(dl1_filename, key=dl1_params_lstcam_key)
-    subarray_info = SubarrayDescription.from_hdf(dl1_filename)
-    tel_id = config["allowed_tels"][0] if "allowed_tels" in config else 1
-    focal_length = subarray_info.tel[tel_id].optics.equivalent_focal_length
+    src_dep_df = get_source_dependent_parameters(dl1_params, config)
+    write_dataframe(src_dep_df, dl1_filename, dl1_params_src_dep_lstcam_key)
  
-    src_dep_df = pd.concat(get_source_dependent_parameters(dl1_params, config, focal_length=focal_length), axis=1)
-
-    metadata = global_metadata()
-    write_dataframe(src_dep_df, dl1_filename, dl1_params_src_dep_lstcam_key, config=config, meta=metadata)
 
 if __name__ == '__main__':
     main()
-
+ 
