@@ -11,9 +11,10 @@ from ctapipe.io.containers import FlatFieldContainer, WaveformCalibrationContain
 
 from ctapipe.io.hdf5tableio import HDF5TableReader
 
-__all__ = ['read_file',
-           'plot_all'
-           ]
+__all__ = [
+    'read_file',
+    'plot_all'
+    ]
 
 ff_data = FlatFieldContainer()
 ped_data = PedestalContainer()
@@ -186,7 +187,7 @@ def plot_all(ped_data, ff_data, calib_data, run=0, plot_file="none"):
         disp.image = image[chan]
         disp.cmap = plt.cm.coolwarm
         disp.set_limits_minmax(0.7, 1.3)
-        plt.title(f'{channel[chan]} relative gain')
+        plt.title(f'{channel[chan]} relative signal')
         #disp.axes.text(lposx, 0, f'{channel[chan]} relative gain', rotation=90)
         disp.add_colorbar()
 
@@ -316,7 +317,7 @@ def plot_all(ped_data, ff_data, calib_data, run=0, plot_file="none"):
         plt.subplot(325)
         plt.tight_layout()
         plt.ylabel('pixels', fontsize=20)
-        plt.xlabel('relative gain', fontsize=20)
+        plt.xlabel('relative signal', fontsize=20)
         median = np.median(gain_median[select])
         rms = np.std(gain_median[select])
         label=f"Relative gain {median:3.2f}, std {rms:5.2f}"
@@ -337,5 +338,6 @@ def plot_all(ped_data, ff_data, calib_data, run=0, plot_file="none"):
         if plot_file != "none":
             pp.savefig(plt.gcf())
 
+
     if plot_file != "none":
-        pp.close()
\ No newline at end of file
+        pp.close()
